@@ -1,5 +1,5 @@
 import os
-from typing import Any, Dict
+from typing import Any, Dict, Callable
 
 from nislmigrate.extensibility.migrator_plugin import MigratorPlugin, ArgumentManager
 from nislmigrate.facades.facade_factory import FacadeFactory
@@ -24,6 +24,9 @@ _METADATA_ONLY_ARGUMENT = 'metadata-only'
 _METADATA_ONLY_HELP = 'When used with --files or --all, migrate only the file metadata, \
 but not the files themselves. Otherwise ignored.'
 
+_CHANGE_FILE_STORE_ARGUMENT = 'change-file-store-root'
+_CHANGE_FILE_STORE_HELP = 'Change the file storage location path'
+
 _NO_FILES_ERROR = """
 
 Files data was not found. If you intend to restore metadata only, pass
@@ -38,6 +41,8 @@ stored in S3. If you intend to migrate metadata only, pass --files-metadata-only
 
 """
 
+_SAVED_OLD_FILE_STORE_ROOT_FILE_NAME = 'file-store-root'
+
 
 class _FileMigratorConfiguration:
     def __init__(
@@ -58,6 +63,8 @@ class _FileMigratorConfiguration:
         self.is_s3_backend: bool = config.get(S3_CONFIGURATION_KEY, '').lower() == 'true'
         self.has_metadata_only_argument: bool = arguments.get(_METADATA_ONLY_ARGUMENT, False)
         self.should_migrate_files: bool = not self.has_metadata_only_argument
+        self.update_store_path: str = arguments.get(_CHANGE_FILE_STORE_ARGUMENT, '')
+        self.should_update_store: bool = not self.update_store_path == ''
 
 
 class FileMigrator(MigratorPlugin):
@@ -81,12 +88,14 @@ class FileMigrator(MigratorPlugin):
             arguments,
             self.config(facade_factory)
         )
-
         configuration.mongo_facade.capture_database_to_directory(
             configuration.mongo_configuration,
             migration_directory,
             self.name)
 
+        captured_file_store_root_path = os.path.join(migration_directory, _SAVED_OLD_FILE_STORE_ROOT_FILE_NAME)
+        configuration.file_facade.write_file(captured_file_store_root_path, configuration.data_directory)
+
         if configuration.should_migrate_files:
             configuration.file_facade.copy_directory(
                 configuration.data_directory,
@@ -106,6 +115,9 @@ class FileMigrator(MigratorPlugin):
             migration_directory,
             self.name)
 
+        if configuration.should_update_store:
+            self.update_root_file_path_in_metadata(configuration)
+
         if configuration.should_migrate_files:
             configuration.file_facade.copy_directory(
                 configuration.file_migration_directory,
@@ -124,7 +136,6 @@ class FileMigrator(MigratorPlugin):
             arguments,
             self.config(facade_factory)
         )
-
         if not configuration.has_metadata_only_argument and configuration.is_s3_backend:
             raise MigrationError(_CANNOT_MIGRATE_S3_FILES_ERROR)
 
@@ -152,3 +163,39 @@ class FileMigrator(MigratorPlugin):
 
     def add_additional_arguments(self, argument_manager: ArgumentManager):
         argument_manager.add_switch(_METADATA_ONLY_ARGUMENT, help=_METADATA_ONLY_HELP)
+        argument_manager.add_argument(_CHANGE_FILE_STORE_ARGUMENT, help=_CHANGE_FILE_STORE_HELP, metavar='update')
+
+    def update_root_file_path_in_metadata(self, configuration: _FileMigratorConfiguration):
+        old_path = configuration.file_facade.read_file(_SAVED_OLD_FILE_STORE_ROOT_FILE_NAME)
+        new_path = configuration.update_store_path
+        collection_name = self.name.lower()
+        does_path_field_start_with_old_path = self.does_path_start_with_prefix_predicate(old_path)
+        replace_old_path_with_new_path = self.replace_path_prefix_in_document_function(old_path, new_path)
+        mongo_configuration = configuration.mongo_configuration
+        configuration.mongo_facade.update_documents_in_collection(
+            mongo_configuration,
+            collection_name,
+            does_path_field_start_with_old_path,
+            replace_old_path_with_new_path)
+
+    @staticmethod
+    def does_path_start_with_prefix_predicate(prefix: str) -> Callable[[Dict[str, Any]], bool]:
+        return lambda document: document['path'].startswith(prefix)
+
+    def replace_path_prefix_in_document_function(
+            self,
+            old_prefix: str,
+            new_prefix: str
+    ) -> Callable[[Dict[str, Any]], Dict[str, Any]]:
+        return lambda document: self.replace_prefix_of_field_in_document('path', old_prefix, new_prefix, document)
+
+    @staticmethod
+    def replace_prefix_of_field_in_document(
+            field: str,
+            old_prefix: str,
+            new_prefix: str,
+            document: Dict[str, Any]
+    ) -> Dict[str, Any]:
+        postfix = document[field][len(old_prefix):]
+        document[field] = new_prefix + postfix
+        return document
