@@ -2,30 +2,24 @@ from nislmigrate.facades.facade_factory import FacadeFactory
 from nislmigrate.extensibility.migrator_plugin import MigratorPlugin
 from nislmigrate.facades.mongo_configuration import MongoConfiguration
 from nislmigrate.facades.mongo_facade import MongoFacade
-
-userdata_dict = {
-    "arg": "userdata",
-    "name": "UserData",
-    "directory_migration": False,
-    "singlefile_migration": False,
-}
+from typing import Any, Dict
 
 
 class UserDataMigrator(MigratorPlugin):
 
     @property
     def name(self):
-        return "UserData"
+        return 'UserData'
 
     @property
     def argument(self):
-        return "userdata"
+        return 'userdata'
 
     @property
     def help(self):
-        return "Migrate user data"
+        return 'Migrate user data'
 
-    def capture(self, migration_directory: str, facade_factory: FacadeFactory):
+    def capture(self, migration_directory: str, facade_factory: FacadeFactory, arguments: Dict[str, Any]):
         mongo_facade: MongoFacade = facade_factory.get_mongo_facade()
         mongo_configuration: MongoConfiguration = MongoConfiguration(self.config(facade_factory))
         mongo_facade.capture_database_to_directory(
@@ -33,7 +27,7 @@ class UserDataMigrator(MigratorPlugin):
             migration_directory,
             self.name)
 
-    def restore(self, migration_directory: str, facade_factory: FacadeFactory):
+    def restore(self, migration_directory: str, facade_factory: FacadeFactory, arguments: Dict[str, Any]):
         mongo_facade: MongoFacade = facade_factory.get_mongo_facade()
         mongo_configuration: MongoConfiguration = MongoConfiguration(self.config(facade_factory))
         mongo_facade.restore_database_from_directory(
@@ -41,7 +35,11 @@ class UserDataMigrator(MigratorPlugin):
             migration_directory,
             self.name)
 
-    def pre_restore_check(self, migration_directory: str, facade_factory: FacadeFactory) -> None:
+    def pre_restore_check(
+            self,
+            migration_directory: str,
+            facade_factory: FacadeFactory,
+            arguments: Dict[str, Any]) -> None:
         mongo_facade: MongoFacade = facade_factory.get_mongo_facade()
         mongo_facade.validate_can_restore_database_from_directory(
             migration_directory,
